// file: MainMenu.java
//

// import necessary java libraries
//
import java.awt.*;
import javax.swing.border.*;
import javax.swing.*;
import java.awt.event.ActionListener;
import java.awt.event.*;
import java.util.*;
import java.io.*;
import java.net.*;
import java.applet.*;

/**
 * MainMenu implements a menu driven system that acts as the primary 
 * control panel for the applet as a whole 
 *
 * hierarchy: JPanel->SubPanel->MainMenu
 */
public class MainMenu extends SubPanel implements ActionListener, ItemListener {

    // *********************************************************************
    //
    // declare global variables and components
    //
    // *********************************************************************

    // declare the menu font layout
    //
    Font currentFont = getFont();
    Font newFont = new Font(currentFont.getName(), currentFont.getStyle(), 12);

    // declare objects needed by the menu sub-components
    //
    OutputFrame magnitudePanel;
    SignalPanel signalPanel;
    SystemPanel systemPanel;
    OutputPanel outputPanel;
    ControlPanel controlPanel;

    // declare the menu layout
    //
    JMenuBar menuBar;
    JMenu menu;
    JMenuItem menuItem;
    JRadioButtonMenuItem rbMenuItem;
    JCheckBoxMenuItem cbMenuItem;
    JCheckBoxMenuItem pauseMenuItem;

    // declare components for the help box
    //
    JFrame frame;     
    JTextArea textArea;
    JScrollPane scrollPane;
    JButton dismiss;

    // declare varaibles to read the help file
    //
    URL url;
    Vector urlvec;
    String document;
    BufferedReader buff;    
    AppletContext context;

    // declare strings for the Help menu
    //
    String helpOption = new String("Help");
    String tutorial = new String("Applet Tutorial");
    String overview = new String("Applet Overview");
    String release = new String("Release Notes");
    String info = new String("Information and Support");
    String plugins = new String("About Plug-ins");
    String done = new String("Dismiss");
    String newline = new String("\n");

    // declare strings for the Parameters menu
    //
    String viewOption = new String("Parameters");
    String goOption = new String("Go");
    String signalParams = new String("Signal");
    String systemParams = new String("System");
    String outputParams = new String("Output");
    String magnitudeParams = new String("Magnitude");
    String signalOption = new String("Signal");
    String systemOption = new String("System");
    String outputOption = new String("Output");
    String magnitudeOption = new String("Magnitude");

    // declare strings for the Go menu
    //
    String animate = new String("Animate");
    String pause = new String("Pause");
    String convolve = new String("Convolve");
    String outClear = new String("Clear");
    String outReset = new String("Reset");
    String spectrum = new String("Spectrum");
    String slow = new String("Slow");
    String medium = new String("Medium");
    String fast = new String("Fast");

    // declare strings for the Signal menu
    //
    String sigClear = new String("signal - Clear");
    String sigReset = new String("signal - Reset");
    String sigSpectrum = new String("signal - Spectrum");

    String sigCustom = new String("signal - Custom");
    String sigCosine = new String("signal - Cosine");
    String sigSinc = new String("signal - Sinc");
    String sigUnit = new String("signal - Unit");
    String sigTriangle = new String("signal - Triangle");
    String sigImpulse = new String("signal - Impulse");
    String sigExp1 = new String("signal - Exp(-t)");
    String sigExp2 = new String("signal - 1 - Exp(-t)");
    String sigExp3 = new String("signal - Exp(-t) * Cosine()");
    String sigLoad = new String("signal - Load Output");

    // declare strings for the System menu
    //
    String sysClear = new String("system - Clear");
    String sysReset = new String("system - Reset");
    String sysSpectrum = new String("system - Spectrum");

    String sysCustom = new String("system - Custom");
    String sysCosine = new String("system - Cosine");
    String sysSinc = new String("system - Sinc");
    String sysUnit = new String("system - Unit");
    String sysTriangle = new String("system - Triangle");
    String sysImpulse = new String("system - Impulse");
    String sysExp1 = new String("system - Exp(-t)");
    String sysExp2 = new String("system - 1 - Exp(-t)");
    String sysExp3 = new String("system - Exp(-t) * Cosine()");
    String sysLoad = new String("system - Load Output");

    // *********************************************************************
    //
    // declare class constructors
    //
    // *********************************************************************
   
    /**
     * default class constructor
     *
     * @param signal SignalPanel object to be set
     * @param system SystemPanel object to be set
     * @param output OutputPanel object to be set
     * @param control ControlPanel object to be set
     * @param mag OutputFrame object to be set to magnitudePanel variable
     * @param vec Vector of urls to be set
     * @param con AppletContext object to be set
     */ 
    public MainMenu (SignalPanel signal, SystemPanel system, 
	      OutputPanel output, ControlPanel control, 
	      OutputFrame mag, Vector vec, AppletContext con) {

	super();

	// initialize the display and control panels
	//
	urlvec = vec;
	context = con;
	magnitudePanel = mag;
	signalPanel = signal;
	systemPanel = system;
	outputPanel = output;
	controlPanel = control;

	// create a border around the control panel
	//
	setBorder(BorderFactory.createEtchedBorder());

	// create components for the help box
	//
	frame = new JFrame();

	// create the textbox to view the help message
	//
	textArea = new JTextArea();
	textArea.setLineWrap(true);
	textArea.setWrapStyleWord(true);
	textArea.setEditable(false);

	// make the text area scrollable
	//
	scrollPane = new JScrollPane(textArea);
	scrollPane.setPreferredSize(new Dimension(400, 450));

	// create a dismiss button for the text area
	//
	dismiss = new JButton(done);
	dismiss.setActionCommand(done);
	dismiss.addActionListener(this);

	// add the components to the frame
	//
	frame.getContentPane().add(scrollPane, BorderLayout.CENTER);
	frame.getContentPane().add(dismiss, BorderLayout.SOUTH);

	// create the menu bar item
	//
	menuBar = new JMenuBar();

	// bulid the signal menu
	//
	menu = new JMenu("Signal");
	menu.setFont(newFont);
	menu.getAccessibleContext().setAccessibleDescription(signalOption);
	menuBar.add(menu);

	// add the custom option to the sub menu
	//
	menuItem = new JMenuItem("Custom");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sigCustom);
	menu.add(menuItem);

	// add the cosine option to the sub menu
	//
	menuItem = new JMenuItem("Cosine");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sigCosine);
	menu.add(menuItem);

	// add the sinc option to the sub menu
	//
	menuItem = new JMenuItem("Sinc");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sigSinc);
	menu.add(menuItem);

	// add the Unit option to the sub menu
	//
	menuItem = new JMenuItem("Unit");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sigUnit);
	menu.add(menuItem);

	// add the Triangle option to the sub menu
	//
	menuItem = new JMenuItem("Triangle");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sigTriangle);
	menu.add(menuItem);

	// add the Impulse option to the sub menu
	//
	menuItem = new JMenuItem("Impulse");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sigImpulse);

	// add the Exp(-t) option to the sub menu
	//
	menuItem = new JMenuItem("Exp(-t)");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sigExp1);
	menu.add(menuItem);

	// add the 1 - Exp(-t) option to the sub menu
	//
	menuItem = new JMenuItem("1 - Exp(-t)");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sigExp2);
	menu.add(menuItem);

	// add the Exp(-t) * Cosine() option to the sub menu
	//
	menuItem = new JMenuItem("Exp(-t) * Cosine()");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sigExp3);
	menu.add(menuItem);

	menuItem = new JMenuItem("Load Output");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sigLoad);

	// add a menu item separator
	//
	menu.addSeparator();

	// add the clear option to the menu
	//
	menuItem = new JMenuItem("Clear");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sigClear);
	menu.add(menuItem);

	// add the reset option to the menu
	//
	menuItem = new JMenuItem("Reset");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sigReset);
	menu.add(menuItem);

	// add the spectrum option to the menu
	//
	menuItem = new JMenuItem("Spectrum");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sigSpectrum);
	menu.add(menuItem);

	// bulid the System menu
	//
	menu = new JMenu("System");
	menu.setFont(newFont);
	menu.getAccessibleContext().setAccessibleDescription(systemOption);
	menuBar.add(menu);

	// add the custom option to the sub menu
	//
	menuItem = new JMenuItem("Custom");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sysCustom);
	menu.add(menuItem);

	// add the cosine option to the sub menu
	//
	menuItem = new JMenuItem("Cosine");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sysCosine);
	menu.add(menuItem);

	// add the sinc option to the sub menu
	//
	menuItem = new JMenuItem("Sinc");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sysSinc);
	menu.add(menuItem);

	// add the Unit option to the sub menu
	//
	menuItem = new JMenuItem("Unit");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sysUnit);
	menu.add(menuItem);

	// add the Triangle option to the sub menu
	//
	menuItem = new JMenuItem("Triangle");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sysTriangle);
	menu.add(menuItem);

	// add the Impulse option to the sub menu
	//
	menuItem = new JMenuItem("Impulse");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sysImpulse);

	// add the Exp(-t) option to the sub menu
	//
	menuItem = new JMenuItem("Exp(-t)");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sysExp1);
	menu.add(menuItem);

	// add the 1 - Exp(-t) option to the sub menu
	//
	menuItem = new JMenuItem("1 - Exp(-t)");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sysExp2);
	menu.add(menuItem);

	// add the Exp(-t) * Cosine() option to the sub menu
	//
	menuItem = new JMenuItem("Exp(-t) * Cosine()");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sysExp3);
	menu.add(menuItem);

	// add the Load Output option to the sub menu
	//
	menuItem = new JMenuItem("Load Output");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sysLoad);

	// add a menu item separator
	//
	menu.addSeparator();

	// add the clear option to the menu
	//
	menuItem = new JMenuItem("Clear");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sysClear);
	menu.add(menuItem);

	// add the reset option to the menu
	//
	menuItem = new JMenuItem("Reset");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sysReset);
	menu.add(menuItem);

	// add the spectrum option to the menu
	//
	menuItem = new JMenuItem("Spectrum");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(sysSpectrum);
	menu.add(menuItem);

	// bulid the signal menu
	//
	menu = new JMenu("Output");
	menu.setFont(newFont);
	menu.getAccessibleContext().setAccessibleDescription(outputOption);
	menuBar.add(menu);

	// add the Clear option to the sub menu
	//
	menuItem = new JMenuItem("Clear");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(outClear);
	menu.add(menuItem);

	// add the Reset option to the sub menu
	//
	menuItem = new JMenuItem("Reset");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(outReset);
	menu.add(menuItem);

	// add the Spectrum option to the sub menu
	//
	menuItem = new JMenuItem("Spectrum");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(spectrum);
	menu.add(menuItem);

	// bulid the view menu
	//
	menu = new JMenu("Parameters");
	menu.setFont(newFont);
	menu.getAccessibleContext().setAccessibleDescription(viewOption);
	menuBar.add(menu);

	// add the signal parameters option to the menu
	//
	menuItem = new JMenuItem(signalParams);
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(signalParams);
	menu.add(menuItem);

	// add the system parameters option to the menu
	//
	menuItem = new JMenuItem(systemParams);
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(systemParams);
	menu.add(menuItem);

	// add the output parameters option to the menu
	//
	menuItem = new JMenuItem(outputParams);
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(outputParams);
	menu.add(menuItem);

	// add the magnitude parameters option to the menu
	//
	menuItem = new JMenuItem(magnitudeParams);
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(magnitudeParams);
	menu.add(menuItem);

	// bulid the Go menu
	//
	menu = new JMenu("Go");
	menu.setFont(newFont);
	menu.getAccessibleContext().setAccessibleDescription(helpOption);
	menuBar.add(menu);

	// add the Animate option to the sub menu
	//
	cbMenuItem = new JCheckBoxMenuItem("Animate");
	cbMenuItem.setFont(newFont);
	cbMenuItem.setSelected(true);
	cbMenuItem.addItemListener(this);
	cbMenuItem.setActionCommand(animate);
	menu.add(cbMenuItem);

	// add the Pause option to the sub menu
	//
	pauseMenuItem = new JCheckBoxMenuItem("Pause");
	pauseMenuItem.setFont(newFont);
	pauseMenuItem.addItemListener(this);
	pauseMenuItem.setActionCommand(pause);
	menu.add(pauseMenuItem);

	// add a menu item separator
	//
	menu.addSeparator();

	// add the Slow option to the sub menu
	//
	menuItem = new JMenuItem("Slow");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(slow);
	menu.add(menuItem);

	// add the Medium option to the sub menu
	//
	menuItem = new JMenuItem("Medium");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(medium);
	menu.add(menuItem);

	// add the Fast option to the sub menu
	//
	menuItem = new JMenuItem("Fast");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(fast);
	menu.add(menuItem);

	// add a menu item separator
	//
	menu.addSeparator();

	// add the Convolve option to the sub menu
	//
	menuItem = new JMenuItem("Convolve");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(convolve);
	menu.add(menuItem);

	// bulid the Help menu
	//
	menu = new JMenu("Help");
	menu.setFont(newFont);
	menu.getAccessibleContext().setAccessibleDescription(helpOption);
	menuBar.add(Box.createHorizontalGlue());
	menuBar.add(menu);

	// add the Release option to the menu
	//
	menuItem = new JMenuItem("Release Notes");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(release);
	menu.add(menuItem);

	// add the Information option to the menu
	//
	menuItem = new JMenuItem("Information and Support");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(info);
	menu.add(menuItem);

	menu.addSeparator();

	// add the Overview option to the menu
	//
	menuItem = new JMenuItem("Applet Overview");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(overview);
	menu.add(menuItem);

	// add the Tutorial option to the menu
	//
	menuItem = new JMenuItem("Applet Tutorial");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(tutorial);
	menu.add(menuItem);

	menu.addSeparator();

	// add the Plug-ins option to the menu
	//
	menuItem = new JMenuItem("About Plug-ins");
	menuItem.setFont(newFont);
	menuItem.addActionListener(this);
	menuItem.setActionCommand(plugins);
	menu.add(menuItem);
    }
   
    // *********************************************************************
    //
    // declare class methods
    //
    // *********************************************************************

    /**
     * adds components to the control panel
     */
    void addComponents() {
	
	constrain(this, menuBar, 0, 0, 
		  GridBagConstraints.REMAINDER, 1,
		  GridBagConstraints.BOTH, 
		  GridBagConstraints.NORTHWEST,
		  1, 1, 0, 0, 0, 0);
    }

    /**
     * method that determines if the hold radio button is set or not and 
     * if so it sets a flag that save the decision region points
     *
     * @param e handles events fired by the action listeners
     */
    public void itemStateChanged(ItemEvent e) {

	JMenuItem source = (JMenuItem)(e.getSource());

	if(source.getText().equals(animate)) {
	    if (e.getStateChange() == ItemEvent.DESELECTED) {
		if (outputPanel.convolveFlag) {
		    source.setSelected(true);
		    return;
		}
		outputPanel.setAnimate(false);
	    } else {
		outputPanel.setAnimate(true);
	    }
	} else if (source.getText().equals(pause)) {
	    if (e.getStateChange() == ItemEvent.DESELECTED) {
		outputPanel.setPause(false);
	    } else {
		if (outputPanel.convolveFlag) {
		    outputPanel.setPause(true);
		}
	    }
	}
    }

    /**
     * method listens for actions taking place on text only menu items
     *
     * @param e handles events fired by the action listeners
     */
    public void actionPerformed(ActionEvent e) {

	// get the source of the action that just occured
	//
	String source = e.getActionCommand();

	// depending on the source of the event take the appropriate action
	//
	if(source.equals(signalParams)) {
	    CardLayout cl = (CardLayout)(controlPanel.cards.getLayout());
	    cl.show(controlPanel.cards, signalParams);
	} else if(source.equals(systemParams)) {
	    CardLayout cl = (CardLayout)(controlPanel.cards.getLayout());
	    cl.show(controlPanel.cards, systemParams);
	} else if(source.equals(outputParams)) {
	    CardLayout cl = (CardLayout)(controlPanel.cards.getLayout());
	    cl.show(controlPanel.cards, outputParams);
	} else if(source.equals(magnitudeParams)) {
	    CardLayout cl = (CardLayout)(controlPanel.cards.getLayout());
	    cl.show(controlPanel.cards, magnitudeParams);
	} else if(source.equals(sigClear)) {
	    signalPanel.wavePanel.presetWave = -1;
	    signalPanel.wavePanel.clearDrawingArea();
	} else if(source.equals(sigReset)) {
	    controlPanel.resetSignalParams();
	} else if(source.equals(sigSpectrum)) {
	    controlPanel.repaintSignal();
	    signalPanel.wavePanel.data.duration = 
		Math.abs(controlPanel.signalXposDiv -
			 controlPanel.signalXnegDiv);
	    signalPanel.wavePanel.writeData();
	    magnitudePanel.initialize(signalPanel.wavePanel.data);
	} else if(source.equals(sigCustom)) {
	    signalPanel.wavePanel.drawCustom();
	} else if(source.equals(sigCosine)) {
	    signalPanel.wavePanel.drawCosine();
	} else if(source.equals(sigSinc)) {
	    signalPanel.wavePanel.drawSinc();
	} else if(source.equals(sigUnit)) {
	    signalPanel.wavePanel.drawUnit();
	} else if(source.equals(sigTriangle)) {
	    signalPanel.wavePanel.drawTriangle();
	} else if(source.equals(sigImpulse)) {
	    signalPanel.wavePanel.drawImpulse();
	} else if(source.equals(sigExp1)) {
	    signalPanel.wavePanel.drawExp();
	} else if(source.equals(sigExp2)) {
	    signalPanel.wavePanel.draw1Exp();
	} else if(source.equals(sigExp3)) {
	    signalPanel.wavePanel.drawExpCosine();
	} else if(source.equals(sigLoad)) {
	    signalPanel.wavePanel.drawCopy(signalPanel.copyData);
	} else if(source.equals(sysClear)) {
	    systemPanel.wavePanel.presetWave = -1;
	    systemPanel.wavePanel.clearDrawingArea();
	} else if(source.equals(sysReset)) {
	    controlPanel.resetSystemParams();
	} else if(source.equals(sysSpectrum)) {
	    controlPanel.repaintSystem();
	    systemPanel.wavePanel.data.duration = 
		Math.abs(controlPanel.systemYposDiv -
			 controlPanel.systemXnegDiv);
	    systemPanel.wavePanel.writeData();
	    magnitudePanel.initialize(systemPanel.wavePanel.data);
	} else if(source.equals(sysCustom)) {
	    systemPanel.wavePanel.drawCustom();
	} else if(source.equals(sysCosine)) {
	    systemPanel.wavePanel.drawCosine();
	} else if(source.equals(sysSinc)) {
	    systemPanel.wavePanel.drawSinc();
	} else if(source.equals(sysUnit)) {
	    systemPanel.wavePanel.drawUnit();
	} else if(source.equals(sysTriangle)) {
	    systemPanel.wavePanel.drawTriangle();
	} else if(source.equals(sysImpulse)) {
	    systemPanel.wavePanel.drawImpulse();
	} else if(source.equals(sysExp1)) {
	    systemPanel.wavePanel.drawExp();
	} else if(source.equals(sysExp2)) {
	    systemPanel.wavePanel.draw1Exp();
	} else if(source.equals(sysExp3)) {
	    systemPanel.wavePanel.drawExpCosine();
	} else if(source.equals(sysLoad)) {
	    systemPanel.wavePanel.drawCopy(systemPanel.copyData);
	} else if(source.equals(slow)) {
	    outputPanel.setSpeed(0.25);
	} else if(source.equals(medium)) {
	    outputPanel.setSpeed(0.50);
	} else if(source.equals(fast)) {
	    outputPanel.setSpeed(0.75);
	} else if(source.equals(convolve)) {

	    if (systemPanel.wavePanel.presetWave == 0) {

		// set the number of pixels to be drawn
		//
		systemPanel.wavePanel.currLimit =
		    systemPanel.wavePanel.getNumPoints();

		// write the data (y-values) to the curve array 
		//
		systemPanel.wavePanel.writeData();
	    }
	    if (signalPanel.wavePanel.presetWave == 0) {

		// set the number of pixels to be drawn
		//
		signalPanel.wavePanel.currLimit =
		    signalPanel.wavePanel.getNumPoints();

		// write the data (y-values) to the curve array 
		//
		signalPanel.wavePanel.writeData();
	    }

	    // convolve the system and input signal
	    //
	    outputPanel.convolve();

	} else if(source.equals(release)) {

	    // clear the text in the text area
            //
            textArea.setText("");

	    // read the help file contents and append them to the text area
	    //
	    try { 

		// get the URL component
		//
		url = (URL)urlvec.elementAt(0);

		// open a file descriptor to read the help file
		//
		InputStreamReader rd = new InputStreamReader(url.openStream());

		// initialize the buffer to read the contents of the help file
		//
		buff = new BufferedReader(rd); 

		// read each line fo the file
		//
		while((document = buff.readLine()) != null) { 

		    // add the help message line to the text area
		    //
		    textArea.append(document + newline);
		}
	    } 
	    catch(IOException ioe) { }

            // display the text area and dismiss button
            //
            frame.pack();
            frame.setVisible(true);
            
	} else if(source.equals(info)) {

	    // clear the text in the text area
            //
            textArea.setText("");

	    // read the help file contents and append them to the text area
	    //
	    try { 

		// get the URL component
		//
		url = (URL)urlvec.elementAt(1);

		// open a file descriptor to read the help file
		//
		InputStreamReader rd = new InputStreamReader(url.openStream());

		// initialize the buffer to read the contents of the help file
		//
		buff = new BufferedReader(rd); 

		// read each line fo the file
		//
		while((document = buff.readLine()) != null) { 

		    // add the help message line to the text area
		    //
		    textArea.append(document + newline);
		}
	    } 
	    catch(IOException ioe) { }

            // display the text area and dismiss button
            //
            frame.pack();
            frame.setVisible(true);

	} else if(source.equals(overview)) {

	    // clear the text in the text area
            //
            textArea.setText("");

	    // read the help file contents and append them to the text area
	    //
	    try { 

		// get the URL component
		//
		url = (URL)urlvec.elementAt(2);

		// open a file descriptor to read the help file
		//
		InputStreamReader rd = new InputStreamReader(url.openStream());

		// initialize the buffer to read the contents of the help file
		//
		buff = new BufferedReader(rd); 

		// read each line fo the file
		//
		while((document = buff.readLine()) != null) { 

		    // add the help message line to the text area
		    //
		    textArea.append(document + newline);
		}
	    } 
	    catch(IOException ioe) { }

            // display the text area and dismiss button
            //
            frame.pack();
            frame.setVisible(true);
            
	} else if(source.equals(tutorial)) {

	    // display the document
	    //
	    try { 

		// get the URL component
		//
		url = (URL)urlvec.elementAt(3);

		// display the url on a seperate browser
		//
		context.showDocument(url, "_blank");
	    } 
	    catch(Exception ae) { }
            
	} else if(source.equals(plugins)) {

	    // clear the text in the text area
            //
            textArea.setText("");
            
	    // read the help file contents and append them to the text area
	    //
	    try { 

		// get the URL component
		//
		url = (URL)urlvec.elementAt(4);

		// open a file descriptor to read the help file
		//
		InputStreamReader rd = new InputStreamReader(url.openStream());

		// initialize the buffer to read the contents of the help file
		//
		buff = new BufferedReader(rd); 

		// read each line fo the file
		//
		while((document = buff.readLine()) != null) { 

		    // add the help message line to the text area
		    //
		    textArea.append(document + newline);
		}
	    } 
	    catch(IOException ioe) { }

            // display the text area and dismiss button
            //
            frame.pack();
            frame.setVisible(true);

	} else if(source.equals(done)) {

	    // remove the frame form the screen
            //
            frame.setVisible(false);

	} else if(source.equals(outClear)) {

	    // reset the pause flag
	    //
	    pauseMenuItem.setSelected(false);
	    outputPanel.setPause(false);

	    // clear the output plots
	    //
	    outputPanel.outDisp.clearDrawingArea();
	    outputPanel.drawingArea.clearDrawingArea();

	} else if(source.equals(outReset)) {
	
	    // reset the output panel parameters
	    //
	    controlPanel.resetOutputParams();

	} else if(source.equals(spectrum)) {
	    
	    // create a frame to diaplay the magnitude spectrum
	    //
	    outputPanel.output.duration = Math.abs(controlPanel.outputXposDiv -
						   controlPanel.outputXnegDiv);
	    magnitudePanel.initialize(outputPanel.output);
	}
    }
}

//
// end of file




