// file: OutputFrame.java
//

// import necessary java libraries
//
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import graph.*;
import java.awt.GraphicsEnvironment.*;

// class: OutputFrame
//
// OutputFrame generates a pop up frame that display the magnitude/phase
// spectrum of the of the samples passed in
//
// hierarchy: JPanel->OutputFrame
//
class OutputFrame extends JPanel implements ActionListener {
    
    // *********************************************************************
    //
    // declare global variables and components
    //
    // *********************************************************************
    
    // declare the toplevel container
    //
    JFrame f1;
    JFrame toplevel;
    
    // declare gui components
    //
    MagResponse magnitude;
    
    // declare components to be added to the window
    //
    JButton dismiss1;
    
    // create an fft object
    //
    FFT fft;
    
    // create a data object
    //
    Data data;
    
    //*****************************************************************
    //
    // declare class constructors 
    //
    //*****************************************************************
    
    // method:  OutputFrame
    //
    // arguments: none
    // returns  : none
    //
    // default constructor that creates a frame to plot the magnitude plot
    //
    OutputFrame() {	
	super();
    }
    
    // *********************************************************************
    //
    // declare class methods
    //
    // *********************************************************************
 
    // method: initialize
    //
    // arguments:
    //    Data d: samples need to compute the magnitude plot
    //
    // return   : none
    //
    // initialize the window components and the magnitude plot object
    //
    public void initialize(Data d) {
	
	// get the data to be plotted
	//
	data = d;

	// define the top level container (frame) 
	//
	f1 = new JFrame();

	// define the gui for the magnitude response
	//
        magnitude = new MagResponse(data);

	// define the button to close the pop-up window
	//
	dismiss1 = new JButton("Dismiss");
	dismiss1.addActionListener(new ActionListener() {
	    public void actionPerformed(ActionEvent e) {
		
		// remove the pop up window
		//
		f1.setVisible(false);
	    }
	});
	
	// define the gui to compute the fft
	//
        fft = new FFT(data);	

        // initialize the window function to all 1's as a default
        //
        data.initializeWindowFunction();

	// add components to the magnitude plot
	//
	addComponents();
    }
    
    // method: addComponents
    //
    // arguments: none
    // return   : none
    //
    // adds a control panel and a canvas to the input panel
    // 
    public void addComponents() {

	// add the container and dismiss button
	//
	f1.getContentPane().add(magnitude, BorderLayout.CENTER);
	f1.getContentPane().add(dismiss1, BorderLayout.SOUTH);

	// add the components to the content pane
	//
	f1.setSize(400,400);
	
	// display the magnitude spectrum window
	//
	f1.setVisible(true);
		
	// appply the window function to the fft data
	//
	data.applyWindow();

	// zero pad the data
	//
	data.zeroPad();

	// time shift the data so that the first point starts at t = 0
	//
	data.timeShift();
	
	// perform the fft on the data
	//
	fft.srfft(data.outputData, data.windowedFFTData);
	
	// output the fft results in the magnitude drawing area
	//
	magnitude.updateScreen();       
    }
    
    // method: actionPerformed
    //
    // arguments:
    //    ActionEvent e: handles events fired by action listeners
    //
    // return   : none
    //
    // handel any action events taking place
    //
    public void actionPerformed(ActionEvent e) {
	// needed since we are implementing ActionListener
    }
}

// 
// end of file



